@@ -57,7 +57,6 @@ imagetypes = {
 try:
     from calibre.utils.magick import Image
     from .six import BytesIO
-    from gif import GifInfo, CHECK_IS_ANIMATED
     convtype = {'jpg':'JPG', 'png':'PNG'}
 
     def convert_image(url,data,sizes,grayscale,
@@ -74,9 +73,6 @@ try:
         nwidth, nheight = sizes
         scaled, nwidth, nheight = fit_image(owidth, oheight, nwidth, nheight)
 
-        if normalize_format_name(img.format)=="gif" and GifInfo(BytesIO(data),CHECK_IS_ANIMATED).frameCount > 1:
-            raise exceptions.RejectImage("Animated gifs come out poorly--not going to use it.")
-
         if scaled:
             img.size = (nwidth, nheight)
             export = True
@@ -164,7 +160,7 @@ def no_convert_image(url,data):
         # parameter.
         ext = url[url.rfind('.')+1:].lower()
         if ext not in imagetypes:
-            logger.debug("no_convert_image url:%s - no known extension"%url)
+            logger.debug("no_convert_image url:%s - no known extension -- using .jpg"%url)
             # doesn't have extension? use jpg.
             ext='jpg'
 
@@ -324,7 +320,11 @@ class InExMatch:
     negate = False
 
     def  __init__(self,line):
-        if "=~" in line:
+        if "=>" in line: # for back-compat when used with replace_metadata conditionals.
+            (self.keys,self.match) = line.split("=>")
+            self.match = self.match.replace(SPACE_REPLACE,' ')
+            self.regex = re_compile(self.match,line)
+        elif "=~" in line:
             (self.keys,self.match) = line.split("=~")
             self.match = self.match.replace(SPACE_REPLACE,' ')
             self.regex = re_compile(self.match,line)
@@ -353,15 +353,19 @@ class InExMatch:
     def in_keys(self,key):
         return key in self.keys
 
-    def is_match(self,value):
+    def is_match(self,param):
+        if not isinstance(param,list):
+            param = [param]
         retval = False
-        if self.regex:
-            if self.regex.search(value):
-                retval = True
-            #print(">>>>>>>>>>>>>%s=~%s r: %s,%s=%s"%(self.match,value,self.negate,retval,self.negate != retval))
-        else:
-            retval = self.match == value
-            #print(">>>>>>>>>>>>>%s==%s r: %s,%s=%s"%(self.match,value,self.negate,retval, self.negate != retval))
+        # print(param)
+        for value in param:
+            if self.regex:
+                if self.regex.search(value):
+                    retval |= True
+                #print(">>>>>>>>>>>>>%s=~%s r: %s,%s=%s"%(self.match,value,self.negate,retval,self.negate != retval))
+            else:
+                retval |= self.match == value
+                #print(">>>>>>>>>>>>>%s==%s r: %s,%s=%s"%(self.match,value,self.negate,retval, self.negate != retval))
 
         return self.negate != retval
 
@@ -387,13 +391,14 @@ def set_in_ex_clude(setting):
     dest = []
     # print("set_in_ex_clude:"+setting)
     for line in setting.splitlines():
+        full_line=line
         if line:
             (match,condmatch)=(None,None)
             if "&&" in line:
                 (line,conditional) = line.split("&&")
                 condmatch = InExMatch(conditional)
             match = InExMatch(line)
-            dest.append([match,condmatch])
+            dest.append([full_line,match,condmatch])
     return dest
 
 ## Two or three part lines.  Two part effect everything.
@@ -407,10 +412,10 @@ def make_replacements(replace):
     for repl_line in replace.splitlines():
         line=repl_line
         try:
-            (metakeys,regexp,replacement,condkey,condregexp)=(None,None,None,None,None)
+            (metakeys,regexp,replacement,cond_match)=(None,None,None,None)
             if "&&" in line:
                 (line,conditional) = line.split("&&")
-                (condkey,condregexp) = conditional.split("=>")
+                cond_match = InExMatch(conditional)
             if "=>" in line:
                 parts = line.split("=>")
                 if len(parts) > 2:
@@ -421,13 +426,11 @@ def make_replacements(replace):
 
             if regexp:
                 regexp = re_compile(regexp,line)
-                if condregexp:
-                    condregexp = re_compile(condregexp,line)
                 # A way to explicitly include spaces in the
                 # replacement string.  The .ini parser eats any
                 # trailing spaces.
                 replacement=replacement.replace(SPACE_REPLACE,' ')
-                retval.append([repl_line,metakeys,regexp,replacement,condkey,condregexp])
+                retval.append([repl_line,metakeys,regexp,replacement,cond_match])
         except Exception as e:
             logger.error("Problem with Replacement Line:%s"%repl_line)
             raise exceptions.PersonalIniFailed(e,'replace_metadata unpacking failed',repl_line)
@@ -488,10 +491,8 @@ class Story(Configurable):
                 if ies:
                     iel = []
                     self.in_ex_cludes[ie] = set_in_ex_clude(ies)
-                    # print("%s %s"%(ie,len(self.in_ex_cludes[ie])))
             self.replacements_prepped = True
 
-
     def set_chapters_range(self,first=None,last=None):
         self.chapter_first=first
         self.chapter_last=last
@@ -533,27 +534,36 @@ class Story(Configurable):
                                             # is_lightweight()
             self.replacements_prepped = False
 
-    def do_in_ex_clude(self,which,value,key):
-        # sets self.replacements and self.in_ex_cludes if needed
-        # do_in_ex_clude is always called from doReplacements, so redundant.
-        # self.prepare_replacements()
+    def getMetadataForConditional(self,key,seen_list={}):
+        if self.getConfig("conditionals_use_lists",True) and not key.endswith("_LIST"):
+            condval = self.getList(key,seen_list=seen_list)
+        else:
+            condval = self.getMetadata(key.replace("_LIST",""),seen_list=seen_list)
+        return condval
 
+    def do_in_ex_clude(self,which,value,key,seen_list):
         if value and which in self.in_ex_cludes:
             include = 'include' in which
             keyfound = False
             found = False
-            for (match,condmatch) in self.in_ex_cludes[which]:
+            for (line,match,cond_match) in self.in_ex_cludes[which]:
                 keyfndnow = False
                 if match.in_keys(key):
+                    if line in seen_list:
+                        logger.info("Skipping %s key(%s) value(%s) line(%s) to prevent infinite recursion."%(which,key,value,line))
+                        continue
                     # key in keys and either no conditional, or conditional matched
-                    if condmatch == None or condmatch.is_key(key):
+                    if cond_match == None or cond_match.is_key(key):
                         keyfndnow = True
                     else:
-                        condval = self.getMetadata(condmatch.key())
-                        keyfndnow = condmatch.is_match(condval)
+                        new_seen_list = dict(seen_list)
+                        new_seen_list[line]=True
+                        # print(cond_match)
+                        condval = self.getMetadataForConditional(cond_match.key(),seen_list=new_seen_list)
+                        keyfndnow = cond_match.is_match(condval)
+                        # print("match:%s %s\ncond_match:%s %s\n\tkeyfound:%s\n\tfound:%s"%(
+                        #         match,value,cond_match,condval,keyfound,found))
                     keyfound |= keyfndnow
-                        # print("match:%s %s\ncondmatch:%s %s\n\tkeyfound:%s\n\tfound:%s"%(
-                        #         match,value,condmatch,condval,keyfound,found))
                     if keyfndnow:
                         found = isinstance(value,basestring) and match.is_match(value)
                     if found:
@@ -571,27 +581,30 @@ class Story(Configurable):
         # sets self.replacements and self.in_ex_cludes if needed
         self.prepare_replacements()
 
-        value = self.do_in_ex_clude('include_metadata_pre',value,key)
-        value = self.do_in_ex_clude('exclude_metadata_pre',value,key)
+        value = self.do_in_ex_clude('include_metadata_pre',value,key,seen_list)
+        value = self.do_in_ex_clude('exclude_metadata_pre',value,key,seen_list)
 
         retlist = [value]
         for replaceline in self.replacements:
-            (repl_line,metakeys,regexp,replacement,condkey,condregexp) = replaceline
-            # recursion on pattern, bail -- Compare by original text
-            # line because I saw an issue with duplicate lines in a
-            # huuuge replace list cause a problem.  Also allows dict()
-            # instead of list() for quicker lookups.
-            if repl_line in seen_list:
-                # print("bailing on %s"%repl_line)
-                continue
+            (repl_line,metakeys,regexp,replacement,cond_match) = replaceline
             #print("replacement tuple:%s"%replaceline)
             if (metakeys == None or key in metakeys) \
                     and isinstance(value,basestring) \
                     and regexp.search(value):
+                # recursion on pattern, bail -- Compare by original text
+                # line because I saw an issue with duplicate lines in a
+                # huuuge replace list cause a problem.  Also allows dict()
+                # instead of list() for quicker lookups.
+                if repl_line in seen_list:
+                    logger.info("Skipping replace_metadata line %s to prevent infinite recursion."%repl_line)
+                    continue
                 doreplace=True
-                if condkey and condkey != key: # prevent infinite recursion.
-                    condval = self.getMetadata(condkey)
-                    doreplace = condval != None and condregexp.search(condval)
+                if cond_match and cond_match.key() != key: # prevent infinite recursion.
+                    new_seen_list = dict(seen_list)
+                    new_seen_list[repl_line]=True
+                    # print(cond_match)
+                    condval = self.getMetadataForConditional(cond_match.key(),seen_list=new_seen_list)
+                    doreplace = condval != None and cond_match.is_match(condval)
 
                 if doreplace:
                     # split into more than one list entry if
@@ -624,8 +637,8 @@ class Story(Configurable):
                             raise
 
         for val in retlist:
-            retlist = list(map(partial(self.do_in_ex_clude,'include_metadata_post',key=key),retlist))
-            retlist = list(map(partial(self.do_in_ex_clude,'exclude_metadata_post',key=key),retlist))
+            retlist = list(map(partial(self.do_in_ex_clude,'include_metadata_post',key=key,seen_list=seen_list),retlist))
+            retlist = list(map(partial(self.do_in_ex_clude,'exclude_metadata_post',key=key,seen_list=seen_list),retlist))
 
         if return_list:
             return retlist
@@ -710,7 +723,8 @@ class Story(Configurable):
 
     def getMetadata(self, key,
                     removeallentities=False,
-                    doreplacements=True):
+                    doreplacements=True,
+                    seen_list={}):
         # check for a cached value to speed processing
         if key in self.processed_metadata_cache \
                 and (removeallentities,doreplacements) in self.processed_metadata_cache[key]:
@@ -724,9 +738,9 @@ class Story(Configurable):
         elif self.isList(key):
             # join_string = self.getConfig("join_string_"+key,u", ").replace(SPACE_REPLACE,' ')
             # value = join_string.join(self.getList(key, removeallentities, doreplacements=True))
-            value = self.join_list(key,self.getList(key, removeallentities, doreplacements=True))
+            value = self.join_list(key,self.getList(key, removeallentities, doreplacements=True,seen_list=seen_list))
             if doreplacements:
-                value = self.doReplacements(value,key+"_LIST")
+                value = self.doReplacements(value,key+"_LIST",seen_list=seen_list)
         elif key in self.metadata:
             value = self.metadata[key]
             if value:
@@ -751,7 +765,7 @@ class Story(Configurable):
                                               'last':commaGroups(last)})
 
             if doreplacements:
-                value=self.doReplacements(value,key)
+                value=self.doReplacements(value,key,seen_list=seen_list)
             if removeallentities and value != None:
                 value = removeAllEntities(value)
         else: #if self.getConfig("default_value_"+key):
@@ -891,7 +905,8 @@ class Story(Configurable):
                 removeallentities=False,
                 doreplacements=True,
                 includelist=[],
-                skip_cache=False):
+                skip_cache=False,
+                seen_list={}):
         #print("getList(%s,%s)"%(listname,includelist))
         retlist = []
 
@@ -912,12 +927,14 @@ class Story(Configurable):
                         ldorepl = False
                     retlist.extend(self.getList(k,removeallentities=False,
                                                 doreplacements=ldorepl,includelist=includelist+[listname],
-                                                skip_cache=True))
+                                                skip_cache=True,
+                                                seen_list=seen_list))
             else:
 
                 if not self.isList(listname):
                     retlist = [self.getMetadata(listname,removeallentities=False,
-                                                doreplacements=doreplacements)]
+                                                doreplacements=doreplacements,
+                                                seen_list=seen_list)]
                 else:
                     retlist = self.getMetadataRaw(listname)
                     if retlist is None:
@@ -944,7 +961,8 @@ class Story(Configurable):
                                 ## logger.debug("x:(%s) y:(%s)"%(x,y))
                                 ## for SPLIT_META(\,)
                                 if x != y and doreplacements: # doreplacements always true here (currently)
-                                    y = self.doReplacements(y,'ships_CHARS',return_list=True)
+                                    y = self.doReplacements(y,'ships_CHARS',return_list=True,
+                                                            seen_list=seen_list)
                                 else:
                                     ## needs to be a list to extend curlist.
                                     y=[x]
@@ -960,7 +978,8 @@ class Story(Configurable):
                 if doreplacements:
                     newretlist = []
                     for val in retlist:
-                        newretlist.extend(self.doReplacements(val,listname,return_list=True))
+                        newretlist.extend(self.doReplacements(val,listname,return_list=True,
+                                                              seen_list=seen_list))
                     retlist = newretlist
 
                 if removeallentities:
@@ -971,7 +990,8 @@ class Story(Configurable):
             if listname == 'genre' and self.getConfig('add_genre_when_multi_category') and len(self.getList('category',
                                                                                                             removeallentities=False,
                                                                                                             # to avoid inf loops if genre/cat substs
-                                                                                                            doreplacements=False
+                                                                                                            doreplacements=False,
+                                                                                                            seen_list=seen_list
                                                                                                             )) > 1:
                 retlist.append(self.getConfig('add_genre_when_multi_category'))
 
